"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Kerberos = void 0;
const axios_1 = require("axios");
const Debug = require("debug");
const debug = Debug('CLOUDPLAT-KERBEROS');
const env = process.env;
class Kerberos {
    constructor({ apiKey = process.env.GATE_KEEPER_API_KEY, appKey, appSecret, roleId, userToken, gateKeeperEndpoint = process.env.GATE_KEEPER_ENDPOINT }) {
        if (!apiKey) {
            throw new Error('Gate keeper api key is required. Please provide it as a valid string or ' +
                'by setting the property GATE_KEEPER_API_KEY as an environment variable');
        }
        if (!appKey) {
            throw new Error('App Key is required.');
        }
        if (!appSecret) {
            throw new Error('App Secret is required.');
        }
        if (!gateKeeperEndpoint) {
            throw new Error('Gate keeper endpoint is required. Please provide it as a valid string or ' +
                'by setting the property GATE_KEEPER_ENDPOINT as an environment variable');
        }
        this.apiKey = apiKey;
        this.gateKeeperEndpoint = gateKeeperEndpoint;
        this.appKey = appKey;
        this.appSecret = appSecret;
        this.roleId = roleId;
        this.userToken = userToken;
    }
    sendRequest(authenticateOnly = false) {
        return axios_1.default({
            url: this.gateKeeperEndpoint,
            method: 'POST',
            headers: {
                'x-api-key': this.apiKey,
                'cache-control': 'no-cache',
                'content-type': 'application/json;charset=utf-8',
            },
            data: JSON.stringify({
                appKey: this.appKey,
                appSecret: this.appSecret,
                roleId: this.roleId,
                userToken: this.userToken,
                authenticateOnly
            })
        });
    }
    authenticateUser() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.userToken) {
                throw new Error('User Token is required.');
            }
            try {
                const response = yield this.sendRequest(true);
                debug('Response received, user is valid');
                return response.data;
            }
            catch (err) {
                debug(err.toString());
            }
            return false;
        });
    }
    /**
     * Get permissions for a user based on a permissions list
     *
     * @returns {Object}
     */
    getUserPermissions() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this.sendRequest();
                debug('Response received, user is valid');
                if (response.data.errorMessage) {
                    throw new Error(response.data.errorMessage);
                }
                return response.data;
            }
            catch (err) {
                debug(err.toString());
            }
            return {};
        });
    }
}
exports.Kerberos = Kerberos;
;
//# sourceMappingURL=index.js.map